/*
 * Copyright 2002-2005 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sf.ldaptemplate;

/**
 * An AuthenticationSource is responsible for providing the principal and
 * credentials to be used when creating a new context.
 * 
 * @author Mattias Arthursson
 * 
 */
public interface AuthenticationSource {
    /**
     * Get the principal to use when creating an authenticated context.
     * 
     * @return the principal (userName).
     */
    public String getPrincipal();

    /**
     * Get the credentials to use when creating an authenticated context.
     * 
     * @return the credentials (userName).
     */
    public String getCredentials();
}
